@@ -1,4 +1,7 @@
 #!/usr/bin/env python3
+import os
+from pathlib import Path
+
 from pytest import fixture
 
 from route_tracker.graph import Graph, add_node
@@ -14,3 +17,10 @@ def starting_graph(empty_graph: Graph) -> Graph:
 @fixture
 def empty_graph() -> Graph:
     return Graph('test_name')
+
+
+@fixture(autouse=True)
+def test_data_dir(tmp_path: Path) -> Path:
+    data_dir = tmp_path
+    os.environ['XDG_DATA_HOME'] = str(data_dir)
+    return data_dir
